@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
@@ -41,7 +40,7 @@ import subprocess
 import sys
 import time
 from argparse import ArgumentParser, Namespace
-from typing import Any, List, Literal, NoReturn, Sequence
+from typing import TYPE_CHECKING, Any, Literal, NoReturn
 
 from univention.config_registry import ConfigRegistry, handler_set, handler_unset
 from univention.lib.policy_result import PolicyResultFailed, policy_result
@@ -52,6 +51,10 @@ from univention.updater.commands import (
 from univention.updater.locking import UpdaterLock, apt_lock
 
 
+if TYPE_CHECKING:
+    from collections.abc import Sequence
+
+
 _JOB = Literal["add", "remove"]
 
 
@@ -65,7 +68,7 @@ configRegistry.load()
 ldap_hostdn = configRegistry.get('ldap/hostdn')
 
 
-class Tee(object):
+class Tee:
     """
     Writes the given string to several files at once. Could by used
     with the print statement
@@ -78,7 +81,7 @@ class Tee(object):
 
     def call(self, command: Sequence[str], **kwargs: Any) -> int:
         p = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, **kwargs)
-        tee_command = ['tee', '-a'] + list(self.files)
+        tee_command = ["tee", "-a", *list(self.files)]
         if self.stdout:
             if self.filter:
                 tee = subprocess.Popen(tee_command, stdin=p.stdout, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
@@ -139,7 +142,7 @@ def check(configRegistry: ConfigRegistry, dist_upgrade: bool = False) -> bool:
     ))
 
 
-def getPackageList(configRegistry: ConfigRegistry, job: _JOB) -> List[str]:
+def getPackageList(configRegistry: ConfigRegistry, job: _JOB) -> list[str]:
     """
     Get a list of packages to remove or add, depending on the value of job.
 
@@ -217,13 +220,13 @@ def run(opt: Namespace) -> int:
             for package in rem_packages:
                 # check if the package exists
                 with apt_lock():
-                    res = subprocess.call(shlex.split(cmd_show) + [package], stdout=logfile, stderr=logfile)
+                    res = subprocess.call([*shlex.split(cmd_show), package], stdout=logfile, stderr=logfile)
                 if res == 0:
                     print("Removing packages: %s" % package)
                     with apt_lock():
                         res = subprocess.call(shlex.split(cmd_config), stdout=logfile, stderr=logfile)
                         if not res:
-                            res = subprocess.call(shlex.split(cmd_remove) + [package], stdout=logfile, stderr=logfile)
+                            res = subprocess.call([*shlex.split(cmd_remove), package], stdout=logfile, stderr=logfile)
                 else:
                     print("The package %s doesn't exist." % package)
                     res = 0
@@ -234,13 +237,13 @@ def run(opt: Namespace) -> int:
             add_packages = getPackageList(configRegistry, 'add')
             for package in add_packages:
                 with apt_lock():
-                    res = subprocess.call(shlex.split(cmd_show) + [package], stdout=logfile, stderr=logfile)
+                    res = subprocess.call([*shlex.split(cmd_show), package], stdout=logfile, stderr=logfile)
                 if res == 0:
                     print("Installing packages: %s" % package)
                     with apt_lock():
                         res = subprocess.call(shlex.split(cmd_config), stdout=logfile, stderr=logfile)
                         if not res:
-                            res = subprocess.call(shlex.split(cmd_install) + [package], stdout=logfile, stderr=logfile)
+                            res = subprocess.call([*shlex.split(cmd_install), package], stdout=logfile, stderr=logfile)
                 else:
                     print("The package %s doesn't exist." % package)
                     res = 0
