@@ -42,7 +42,7 @@ fi
 ###CHECKS_COMMON###
 
 VERSION="52"  # we don't put 51 here because the upgrade should look like upgrading to UCS 5.2
-VERSION_NAME="5.1"
+VERSION_NAME="5.2"
 MIN_VERSION="5.0-7"
 MIN_VERSION_SYSTEM="5.0-9-1204"
 
@@ -504,7 +504,7 @@ update_check_disk_space () {
 		then
 			echo "	Not enough space in $partition, need at least $usersize."
 			echo "	This may interrupt the update and result in an inconsistent system!"
-			if [ "$partition" = "/boot" ] && [ "$update51_pruneoldkernel" != "yes" ]
+			if [ "$partition" = "/boot" ] && [ "$update52_pruneoldkernel" != "yes" ]
 			then
 				echo
 				echo "	Old kernel versions on /boot/ can be pruned by manully by running"
@@ -602,9 +602,11 @@ if blocking_computers or blocking_objects:
 update_check_user_country_mapping () {
 	# https://forge.univention.org/bugzilla/show_bug.cgi?id=56528
 	is_ucr_false directory/manager/web/modules/users/user/map-country-to-st && return 0
+	[ "$server_role" = "domaincontroller_master" ] || return 0
+
 	echo '	Users in LDAP need to be migrated so their "country" property is stored'
 	echo '	in the correct LDAP attribute "c" instead of in the state ("st").'
-	echo '	UCS 5.0 supported both configurations. With UCS 5.1 only the correct mapping'
+	echo '	UCS 5.0 supported both configurations. With UCS 5.2 only the correct mapping'
 	echo '	is supported. A migration is necessary before upgrading.'
 	echo ""
 	echo '	The migration can be performed using the command'
@@ -662,19 +664,6 @@ update_check_for_postgresql96 () {
 	return 1
 }
 
-# block update if SELinux is still active (Bug #57902)
-update_check_selinux_deactivated() {
-	[ -e /sys/fs/selinux/deny_unknown ] || return 0
-
-	local var="update$VERSION/ignore_selinux_active"
-	ignore_check "$var" && return 100
-
-	echo "	The file /sys/fs/selinux/deny_unknown exists indicating that SELinux is still active."
-	echo "	Please reboot the system to let errata update 5.0x873 take effect."
-	echo "	The update can be started after SELinux has been disabled."
-	return 1
-}
-
 checks () {
 	# stderr to log
 	exec 2>>"$UPDATER_LOG"
