@@ -86,15 +86,9 @@ memberserver) apt_install univention-server-member ;;
 *) die "The server role '$server_role' is not supported!" ;;
 esac
 
-# Issue univention/ucs#2542: make sure we keep univention-appcenter-docker
-if [ -n "$(ucr get docker/daemon/default/map/log-opt)" ]; then
-	ucr unset docker/daemon/default/map/log-opt && ucr commit /etc/default/docker
-fi
-is_ucr_true update/510/univention-appcenter-docker && univention-install -y univention-appcenter-docker && ucr unset update/510/univention-appcenter-docker
-
-# Issue univention/ucs#2548: make sure we keep univention-monitoring-client and univention-nagios-client
-is_ucr_true update/510/univention-monitoring-client && univention-install -y univention-monitoring-client && ucr unset update/510/univention-monitoring-client
-is_ucr_true update/510/univention-nagios-client && univention-install -y univention-nagios-client && ucr unset update/510/univention-nagios-client
+# Issue univention/ucs#2549
+is_ucr_true update52/skip/autoremove ||
+	DEBIAN_FRONTEND=noninteractive apt-get -y remove python2.7 python2.7-minimal libpython2.7-stdlib libpython2.7-minimal >&3 2>&3
 
 is_ucr_true update52/skip/autoremove ||
 	DEBIAN_FRONTEND=noninteractive apt-get -y --allow-unauthenticated --allow-downgrades --allow-remove-essential --allow-change-held-packages autoremove >&3 2>&3
@@ -103,8 +97,8 @@ is_ucr_true update52/skip/autoremove ||
 rm -f /etc/apt/sources.list.d/00_ucs_temporary_installation.list
 
 # removing the atd service conf file that is setting the KillMode attribute
-if [ -e "/etc/systemd/system/atd.service.d/update510.conf" ]; then
-	rm -f /etc/systemd/system/atd.service.d/update510.conf
+if [ -e "/etc/systemd/system/atd.service.d/update520.conf" ]; then
+	rm -f /etc/systemd/system/atd.service.d/update520.conf
 	rmdir --ignore-fail-on-non-empty /etc/systemd/system/atd.service.d/
 	systemctl daemon-reload
 fi
@@ -149,20 +143,36 @@ find /usr/lib/python3/dist-packages/ -type d -not -perm 755 -name __pycache__ -e
 
 
 # Bug #52923 #57296: switch back to old fetchmail/autostart status
-if [ -n "$(ucr search "^fetchmail/autostart/update510$")" ] ; then
-	eval "$(ucr shell fetchmail/autostart/update510)"
-	if [ -z "$fetchmail_autostart_update510" ] ; then
+if [ -n "$(ucr search "^fetchmail/autostart/update520$")" ] ; then
+	eval "$(ucr shell fetchmail/autostart/update520)"
+	if [ -z "$fetchmail_autostart_update520" ] ; then
 		ucr unset fetchmail/autostart >&3 2>&3
 	else
-		ucr set fetchmail/autostart="$fetchmail_autostart_update510" >&3 2>&3
+		ucr set fetchmail/autostart="$fetchmail_autostart_update520" >&3 2>&3
 	fi
-	ucr unset fetchmail/autostart/update510 >&3 2>&3
+	ucr unset fetchmail/autostart/update520 >&3 2>&3
 	echo "Please note:" >&3
 	echo "The following fetchmail restart might fail if fetchmail is unconfigured." >&3
 	echo "This is usually no error." >&3
 	systemctl restart fetchmail >&3 2>&3
 fi
 
+if [ "${server_role:-}" = "domaincontroller_master" ]; then
+	if univention-ldapsearch -LLL '(uid=ucs-sso)' 1.1 | grep -q '^dn'; then
+		udm users/user remove --dn="uid=ucs-sso,cn=users,$(ucr get ldap/base)"
+	fi
+fi
+rm -f /etc/simplesamlphp.keytab /etc/simplesamlphp/ucs-sso-kerberos.secret
+
+# remove pinning after upgrade
+rm -f /etc/apt/preferences.d/99ucs520.pref /etc/apt/apt.conf.d/99ucs520
+
+# remove backup packages sources
+rm -f /etc/apt/sources.list.d/15_ucs-online-version.list.upgrade510.bak
+rm -f /etc/apt/sources.list.d/20_ucs-online-component.list.upgrade510.bak
+rm -f /etc/apt/sources.list.d/15_ucs-online-version.list.upgrade520.bak
+rm -f /etc/apt/sources.list.d/20_ucs-online-component.list.upgrade520.bak
+
 echo "
 
 
