@@ -57,15 +57,8 @@ readcontinue () {
 echo
 echo "HINT:"
 echo "Please check the release notes carefully BEFORE updating to UCS ${UPDATE_NEXT_VERSION}:"
-echo ""
-echo "UCS 5.1-0 is an intermediate release and must not be used in production."
-echo "After the update to UCS 5.1-0 make sure to immediately update to UCS 5.2-0,"
-echo "the updater will ask you to do so."
-echo ""
-echo "All the necessary information is therefore in the release notes for UCS 5.2-0."
-echo ""
-echo " English version: https://docs.software-univention.de/release-notes/5.2-0/en/"
-echo " German version:  https://docs.software-univention.de/release-notes/5.2-0/de/"
+echo " English version: https://docs.software-univention.de/release-notes/${UPDATE_NEXT_VERSION}/en/"
+echo " German version:  https://docs.software-univention.de/release-notes/${UPDATE_NEXT_VERSION}/de/"
 echo
 echo "Please also consider documents of following release updates and"
 echo "3rd party components."
@@ -143,8 +136,8 @@ mv /boot/*.bak "$initrd_backup" >/dev/null 2>&1
 
 # Bug #52923 #57296: disable fetchmail during update to prevent aborting update
 if dpkg -l univention-fetchmail 2>&3 | grep ^ii  >&3 ; then
-	if [ -z "$(ucr search "^fetchmail/autostart/update510$")" ] ; then
-		ucr set fetchmail/autostart/update510="$(ucr get fetchmail/autostart)" >&3
+	if [ -z "$(ucr search "^fetchmail/autostart/update520$")" ] ; then
+		ucr set fetchmail/autostart/update520="$(ucr get fetchmail/autostart)" >&3
 	fi
 	ucr set fetchmail/autostart=no >&3 2>&3
 	systemctl stop fetchmail >&3 2>&3 || :
@@ -153,7 +146,7 @@ fi
 # set KillMode of atd service to process to save the children from getting killed
 # up to this point the updater process is a child of atd as well
 install -m 0755 -o root -g root -d /etc/systemd/system/atd.service.d
-echo -en "[Service]\nKillMode=process" > /etc/systemd/system/atd.service.d/update510.conf
+echo -en "[Service]\nKillMode=process" > /etc/systemd/system/atd.service.d/update520.conf
 systemctl daemon-reload
 
 # ensure that en_US is included in list of available locales (Bug #44150)
@@ -166,39 +159,29 @@ esac
 is_ucr_true update52/skip/autoremove ||
 	DEBIAN_FRONTEND=noninteractive apt-get -y --allow-unauthenticated --allow-downgrades --allow-remove-essential --allow-change-held-packages autoremove >&3 2>&3
 
+[ -f /etc/apt/preferences.d/99ucs520.pref ] ||
+cat >/etc/apt/preferences.d/99ucs520.pref <<__PREF__
+Package: runc
+Pin: release l=Univention Corporate Server, v=5.2.0
+Pin-Priority: 1001
+__PREF__
+[ -f /etc/apt/apt.conf.d/99ucs520 ] || echo 'APT::Get::Allow-Downgrades "true";' >/etc/apt/apt.conf.d/99ucs520
+
+
+# univention/ucs#1945 - disable php7.4 and php7.0
+a2dismod php7.4 || true
+a2dismod php7.0 || true
+
 deactivate_old_package_sources () {
-	# disable UCS 5.0 package sources to avoid mixing package versions during update
+	# disable UCS 5.1 package sources to avoid mixing package versions during update
 	local sources_lists
 	sources_lists=("/etc/apt/sources.list.d/15_ucs-online-version.list" "/etc/apt/sources.list.d/20_ucs-online-component.list")
 	for sources_list in "${sources_lists[@]}"; do
-		mv "$sources_list" "${sources_list}.upgrade510.bak"
+		mv "$sources_list" "${sources_list}.upgrade520.bak"
 	done
 }
 deactivate_old_package_sources
 
-# Issue univention/ucs#2542: make sure we keep univention-appcenter-docker
-if dpkg -l univention-appcenter-docker 2>&3 | grep ^ii  >&3 ; then
-	ucr set update/510/univention-appcenter-docker=true
-fi
-
-# Issue univention/ucs#2548: make sure we keep univention-monitoring-client and univention-nagios-client
-if dpkg -l univention-monitoring-client 2>&3 | grep ^ii  >&3 ; then
-  ucr set update/510/univention-monitoring-client=true
-fi
-if dpkg -l univention-nagios-client 2>&3 | grep ^ii  >&3 ; then
-  ucr set update/510/univention-nagios-client=true
-fi
-
-# univention/ucs#1945 - disable php7.0
-# apache2: Syntax error on line 146 of /etc/apache2/apache2.conf: Syntax error on line 3 of /etc/apache2/mods-enabled/php7.0.load:
-#          Cannot load /usr/lib/apache2/modules/libphp7.0.so into server: /usr/lib/apache2/modules/libphp7.0.so:
-#          cannot open shared object file: No such file or directory Action '--configtest' failed.
-a2dismod php7.0 || true
-
-# univention/ucs#1951 - dirty hack to migrate the app scripts from py2 to py2 (admin-dashboard)
-test -e /usr/sbin/univention-dashboard-management && sed -i s'|/usr/bin/python2.7|/usr/bin/python3|' /usr/sbin/univention-dashboard-management
-test -e /usr/sbin/univention-metrics-domain && sed -i s'|/usr/bin/python2.7|/usr/bin/python3|' /usr/sbin/univention-metrics-domain
-
 # Pre-upgrade
 preups=""
 ${update_commands_update:-false} >&3 2>&3
